@@ -92,7 +92,7 @@ update_model <- function(x, spec, ..., formula = NULL) {
 
 # ------------------------------------------------------------------------------
 
-fit.action_model <- function(object, workflow, control) {
+fit.action_model <- function(object, workflow, control, ...) {
   if (!is_control_workflow(control)) {
     abort("`control` must be a workflows control object created by `control_workflow()`.")
   }
