@@ -19,7 +19,9 @@
 #'
 #' @param x A workflow
 #'
-#' @param recipe A recipe created using [recipes::recipe()]
+#' @param recipe A recipe created using [recipes::recipe()]. The recipe
+#'    should not have been trained already with [recipes::prep()]; workflows
+#'    will handle training internally.
 #'
 #' @param ... Not used.
 #'
@@ -86,7 +88,7 @@ update_recipe <- function(x, recipe, ..., blueprint = NULL) {
 
 # ------------------------------------------------------------------------------
 
-fit.action_recipe <- function(object, workflow, data) {
+fit.action_recipe <- function(object, workflow, data, ...) {
   recipe <- object$recipe
   blueprint <- object$blueprint
 
@@ -130,6 +132,10 @@ new_action_recipe <- function(recipe, blueprint, ..., call = caller_env()) {
     abort("`recipe` must be a recipe.", call = call)
   }
 
+  if (recipes::fully_trained(recipe)) {
+    abort("Can't add a trained recipe to a workflow.", call = call)
+  }
+
   # `NULL` blueprints are finalized at fit time
   if (!is_null(blueprint) && !is_recipe_blueprint(blueprint)) {
     abort("`blueprint` must be a hardhat 'recipe_blueprint'.", call = call)
