@@ -17,7 +17,8 @@
 #' @param object A workflow that has been fit by [fit.workflow()]
 #'
 #' @param new_data A data frame containing the new predictors to preprocess
-#'   and predict on
+#'   and predict on. If using a recipe preprocessor, you should not call
+#'   [recipes::bake()] on `new_data` before passing to this function.
 #'
 #' @return
 #' A data frame of model predictions, with as many rows as `new_data` has.
@@ -29,8 +30,8 @@
 #' library(recipes)
 #' library(magrittr)
 #'
-#' training <- mtcars[1:20,]
-#' testing <- mtcars[21:32,]
+#' training <- mtcars[1:20, ]
+#' testing <- mtcars[21:32, ]
 #'
 #' model <- linear_reg() %>%
 #'   set_engine("lm")
@@ -52,7 +53,10 @@ predict.workflow <- function(object, new_data, type = NULL, opts = list(), ...)
   workflow <- object
 
   if (!is_trained_workflow(workflow)) {
-    abort("Workflow has not yet been trained. Do you need to call `fit()`?")
+    abort(c(
+      "Can't predict on an untrained workflow.",
+      i = "Do you need to call `fit()`?"
+    ))
   }
 
   fit <- extract_fit_parsnip(workflow)
